@@ -2000,10 +2000,15 @@ Note that NaN has the property that NaN != NaN, so you need 'is_nan(x)' rather t
 			name:  "fmtnum",
 			class: FUNC_CLASS_CONVERSION,
 			help: `Convert int/float/bool to string using printf-style format string (https://pkg.go.dev/fmt), e.g.
-'$s = fmtnum($n, "%08d")' or '$t = fmtnum($n, "%.6e")'. This function recurses on array and map values.`,
+'$s = fmtnum($n, "%08d")' or '$t = fmtnum($n, "%.6e")'. Miller-specific extension: "%_d" and "%_f" for comma-separated thousands. This function recurses on array and map values.`,
 			binaryFunc: bifs.BIF_fmtnum,
 			examples: []string{
-				`$x = fmtnum($x, "%.6f")`,
+				`$y = fmtnum($x, "%.6f")`,
+				`$o = fmtnum($n, "%d")`,
+				`$o = fmtnum($n, "%12d")`,
+				`$y = fmtnum($x, "%.6_f")`,
+				`$o = fmtnum($n, "%_d")`,
+				`$o = fmtnum($n, "%12_d")`,
 			},
 		},
 
