@@ -76,16 +76,16 @@ func (reader *RecordReaderTSV) Read(
 			)
 			if err != nil {
 				errorChannel <- err
-				return
+			} else {
+				reader.processHandle(
+					handle,
+					"(stdin)",
+					&context,
+					readerChannel,
+					errorChannel,
+					downstreamDoneChannel,
+				)
 			}
-			reader.processHandle(
-				handle,
-				"(stdin)",
-				&context,
-				readerChannel,
-				errorChannel,
-				downstreamDoneChannel,
-			)
 		} else {
 			for _, filename := range filenames {
 				handle, err := lib.OpenFileForRead(
@@ -96,17 +96,17 @@ func (reader *RecordReaderTSV) Read(
 				)
 				if err != nil {
 					errorChannel <- err
-					return
+				} else {
+					reader.processHandle(
+						handle,
+						filename,
+						&context,
+						readerChannel,
+						errorChannel,
+						downstreamDoneChannel,
+					)
+					handle.Close()
 				}
-				reader.processHandle(
-					handle,
-					filename,
-					&context,
-					readerChannel,
-					errorChannel,
-					downstreamDoneChannel,
-				)
-				handle.Close()
 			}
 		}
 	}
@@ -126,9 +126,9 @@ func (reader *RecordReaderTSV) processHandle(
 	reader.headerStrings = nil
 
 	recordsPerBatch := reader.recordsPerBatch
-	lineScanner := NewLineScanner(handle, reader.readerOptions.IRS)
+	lineReader := NewLineReader(handle, reader.readerOptions.IRS)
 	linesChannel := make(chan *list.List, recordsPerBatch)
-	go channelizedLineScanner(lineScanner, linesChannel, downstreamDoneChannel, recordsPerBatch)
+	go channelizedLineReader(lineReader, linesChannel, downstreamDoneChannel, recordsPerBatch)
 
 	for {
 		recordsAndContexts, eof := reader.recordBatchGetter(reader, linesChannel, filename, context, errorChannel)
